@@ -403,7 +403,8 @@ class Appmenus(object):
             appmenus_to_remove = [
                 x for x in appmenus_to_remove
                 if not x.startswith(self.qubes_vm_desktop) and
-                   not x.startswith('qubes-vm-directory-')]
+                   not x.startswith('qubes-vm-directory-') and
+                   not x.startswith(self.qubes_vm_desktop_settings)]
         self._do_remove_appmenus(vm, appmenus_to_remove, appmenus_dir,
                 refresh_cache)
 
@@ -692,7 +693,7 @@ class Appmenus(object):
                 'kbuildsycoca' + os.environ.get('KDE_SESSION_VERSION', '4')])
 
 
-parser = qubesadmin.tools.QubesArgumentParser()
+parser = qubesadmin.tools.QubesArgumentParser(show_forceroot=True)
 
 parser_stdin_mode = parser.add_mutually_exclusive_group()
 
